#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 doctest-driver-gen
version:              0.3.0.8
visibility:           public
id:                   doctest-driver-gen-0.3.0.8-60Tuup1NP9S9LYRQu4lUor
key:                  doctest-driver-gen-0.3.0.8-60Tuup1NP9S9LYRQu4lUor
license:              BSD-3-Clause
copyright:            (C) Hexirp 2017-2023
maintainer:           https://github.com/Hexirp/doctest-driver-gen/issues
author:               Hexirp
homepage:             https://github.com/Hexirp/doctest-driver-gen#readme
synopsis:             Generate driver file for doctest'\''s cabal integration
description:
    doctest-driver-gen is a doctest'\''s driver file generator.
    It lets you automatically generate driver file for
    doctest'\''s cabal integration.

category:             Testing
abi:                  4c7ad49794cbb8448e4671d885e42813
exposed:              True
exposed-modules:      Test.DocTest.Gen
import-dirs:          /usr/lib/ghc-9.6.6/site-local/doctest-driver-gen-0.3.0.8
library-dirs:         /usr/lib/ghc-9.6.6/site-local/doctest-driver-gen-0.3.0.8
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/doctest-driver-gen-0.3.0.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-doctest-driver-gen
hs-libraries:         HSdoctest-driver-gen-0.3.0.8-60Tuup1NP9S9LYRQu4lUor
depends:              base-4.18.2.1
haddock-interfaces:
    /usr/share/doc/haskell-doctest-driver-gen/html/doctest-driver-gen.haddock

haddock-html:         /usr/share/doc/haskell-doctest-driver-gen/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

